dm: treewide: Rename 'platdata' variables to just 'plat'

We use 'priv' for private data but often use 'platdata' for platform data.
We can't really use 'pdata' since that is ambiguous (it could mean private
or platform data).

Rename some of the latter variables to end with 'plat' for consistency.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/blk.h b/include/blk.h
index 9ee10fb..c4401b0 100644
--- a/include/blk.h
+++ b/include/blk.h
@@ -56,7 +56,7 @@
 
 /*
  * With driver model (CONFIG_BLK) this is uclass platform data, accessible
- * with dev_get_uclass_platdata(dev)
+ * with dev_get_uclass_plat(dev)
  */
 struct blk_desc {
 	/*
diff --git a/include/cpu.h b/include/cpu.h
index 78e88b9..1d53308 100644
--- a/include/cpu.h
+++ b/include/cpu.h
@@ -17,7 +17,7 @@
  * @timebase_freq: the current frequency at which the cpu timer timebase
  *		   registers are updated (in Hz)
  *
- * This can be accessed with dev_get_parent_platdata() for any UCLASS_CPU
+ * This can be accessed with dev_get_parent_plat() for any UCLASS_CPU
  * device.
  */
 struct cpu_platdata {
diff --git a/include/dm/lists.h b/include/dm/lists.h
index 810e244..070bc9c 100644
--- a/include/dm/lists.h
+++ b/include/dm/lists.h
@@ -16,7 +16,7 @@
  * lists_driver_lookup_name() - Return u_boot_driver corresponding to name
  *
  * This function returns a pointer to a driver given its name. This is used
- * for binding a driver given its name and platdata.
+ * for binding a driver given its name and plat.
  *
  * @name: Name of driver to look up
  * @return pointer to driver, or NULL if not found
diff --git a/include/dm/pci.h b/include/dm/pci.h
index 10f9fd9..bddacbf 100644
--- a/include/dm/pci.h
+++ b/include/dm/pci.h
@@ -30,7 +30,7 @@
  *
  * This returns an int to avoid a dependency on pci.h
  *
- * @reg: reg value from dt-platdata.c array (first member). This is not a
+ * @reg: reg value from dt-plat.c array (first member). This is not a
  *	pointer type, since the caller may use fdt32_t or fdt64_t depending on
  *	the address sizes.
  * @return device/function for that device (pci_dev_t format)
diff --git a/include/dm/platdata.h b/include/dm/platdata.h
index 216efa8..6094b66 100644
--- a/include/dm/platdata.h
+++ b/include/dm/platdata.h
@@ -20,13 +20,13 @@
  * available). U-Boot's driver model uses device tree for configuration.
  *
  * @name:	Driver name
- * @platdata:	Driver-specific platform data
+ * @plat:	Driver-specific platform data
  * @platdata_size: Size of platform data structure
  * @parent_idx:	Index of the parent driver_info structure
  */
 struct driver_info {
 	const char *name;
-	const void *platdata;
+	const void *plat;
 #if CONFIG_IS_ENABLED(OF_PLATDATA)
 	unsigned short platdata_size;
 	short parent_idx;
@@ -57,7 +57,7 @@
  * available). U-Boot's driver model uses device tree for configuration.
  *
  * When of-platdata is in use, U_BOOT_DEVICE() cannot be used outside of the
- * dt-platdata.c file created by dtoc
+ * dt-plat.c file created by dtoc
  */
 #if CONFIG_IS_ENABLED(OF_PLATDATA) && !defined(DT_PLATDATA_C)
 #define U_BOOT_DEVICE(__name)	_Static_assert(false, \
diff --git a/include/dm/root.h b/include/dm/root.h
index 830e313..113e92e 100644
--- a/include/dm/root.h
+++ b/include/dm/root.h
@@ -33,7 +33,7 @@
 /**
  * dm_scan_platdata() - Scan all platform data and bind drivers
  *
- * This scans all available platdata and creates drivers for each
+ * This scans all available plat and creates drivers for each
  *
  * @pre_reloc_only: If true, bind only drivers with the DM_FLAG_PRE_RELOC
  * flag. If false bind all drivers.
diff --git a/include/dwmmc.h b/include/dwmmc.h
index c536946..4515a44 100644
--- a/include/dwmmc.h
+++ b/include/dwmmc.h
@@ -256,7 +256,7 @@
  * ...
  *
  * Inside U_BOOT_DRIVER():
- *	.platdata_auto	= sizeof(struct rockchip_mmc_plat),
+ *	.plat_auto	= sizeof(struct rockchip_mmc_plat),
  *
  * To access platform data:
  *	struct rockchip_mmc_plat *plat = dev_get_platdata(dev);
diff --git a/include/i2c.h b/include/i2c.h
index 880aa80..d0a3901 100644
--- a/include/i2c.h
+++ b/include/i2c.h
@@ -71,7 +71,7 @@
  * An I2C chip is a device on the I2C bus. It sits at a particular address
  * and normally supports 7-bit or 10-bit addressing.
  *
- * To obtain this structure, use dev_get_parent_platdata(dev) where dev is
+ * To obtain this structure, use dev_get_parent_plat(dev) where dev is
  * the chip to examine.
  *
  * @chip_addr:	Chip address on bus
diff --git a/include/net.h b/include/net.h
index aff6674..13da69b 100644
--- a/include/net.h
+++ b/include/net.h
@@ -115,7 +115,7 @@
  * @enetaddr: The Ethernet MAC address that is loaded from EEPROM or env
  * @phy_interface: PHY interface to use - see PHY_INTERFACE_MODE_...
  * @max_speed: Maximum speed of Ethernet connection supported by MAC
- * @priv_pdata: device specific platdata
+ * @priv_pdata: device specific plat
  */
 struct eth_pdata {
 	phys_addr_t iobase;
diff --git a/include/pci.h b/include/pci.h
index d1ccf6c..a8472dd 100644
--- a/include/pci.h
+++ b/include/pci.h
@@ -903,7 +903,7 @@
  *
  * Every device on a PCI bus has this per-child data.
  *
- * It can be accessed using dev_get_parent_platdata(dev) if dev->parent is a
+ * It can be accessed using dev_get_parent_plat(dev) if dev->parent is a
  * PCI bus (i.e. UCLASS_PCI)
  *
  * @devfn:	Encoded device and function index - see PCI_DEVFN()
diff --git a/include/remoteproc.h b/include/remoteproc.h
index 74d0172..089131f 100644
--- a/include/remoteproc.h
+++ b/include/remoteproc.h
@@ -34,7 +34,7 @@
  * @mem_type: one of 'enum rproc_mem_type'
  * @driver_plat_data: driver specific platform data that may be needed.
  *
- * This can be accessed with dev_get_uclass_platdata() for any UCLASS_REMOTEPROC
+ * This can be accessed with dev_get_uclass_plat() for any UCLASS_REMOTEPROC
  * device.
  *
  */
diff --git a/include/sdhci.h b/include/sdhci.h
index d04afd5..69c2087 100644
--- a/include/sdhci.h
+++ b/include/sdhci.h
@@ -440,7 +440,7 @@
  * ...
  *
  * Inside U_BOOT_DRIVER():
- *	.platdata_auto	= sizeof(struct msm_sdhc_plat),
+ *	.plat_auto	= sizeof(struct msm_sdhc_plat),
  *
  * To access platform data:
  *	struct msm_sdhc_plat *plat = dev_get_platdata(dev);
diff --git a/include/spi.h b/include/spi.h
index f69c08d..176a42c 100644
--- a/include/spi.h
+++ b/include/spi.h
@@ -48,8 +48,8 @@
  * struct dm_spi_platdata - platform data for all SPI slaves
  *
  * This describes a SPI slave, a child device of the SPI bus. To obtain this
- * struct from a spi_slave, use dev_get_parent_platdata(dev) or
- * dev_get_parent_platdata(slave->dev).
+ * struct from a spi_slave, use dev_get_parent_plat(dev) or
+ * dev_get_parent_plat(slave->dev).
  *
  * This data is immuatable. Each time the device is probed, @max_hz and @mode
  * will be copied to struct spi_slave.
@@ -566,12 +566,12 @@
  * is automatically bound on this chip select with requested speed and mode.
  *
  * Ths new slave device is probed ready for use with the speed and mode
- * from platdata when available or the requested values.
+ * from plat when available or the requested values.
  *
  * @busnum:	SPI bus number
  * @cs:		Chip select to look for
- * @speed:	SPI speed to use for this slave when not available in platdata
- * @mode:	SPI mode to use for this slave when not available in platdata
+ * @speed:	SPI speed to use for this slave when not available in plat
+ * @mode:	SPI mode to use for this slave when not available in plat
  * @drv_name:	Name of driver to attach to this chip select
  * @dev_name:	Name of the new device thus created
  * @busp:	Returns bus device
diff --git a/include/usb.h b/include/usb.h
index 5a7af88..a3323f5 100644
--- a/include/usb.h
+++ b/include/usb.h
@@ -608,7 +608,7 @@
 /**
  * struct usb_dev_platdata - Platform data about a USB device
  *
- * Given a USB device dev this structure is dev_get_parent_platdata(dev).
+ * Given a USB device dev this structure is dev_get_parent_plat(dev).
  * This is used by sandbox to provide emulation data also.
  *
  * @id:		ID used to match this device
@@ -662,7 +662,7 @@
  * struct usb_emul_platdata - platform data about the USB emulator
  *
  * Given a USB emulator (UCLASS_USB_EMUL) 'dev', this is
- * dev_get_uclass_platdata(dev).
+ * dev_get_uclass_plat(dev).
  *
  * @port1:	USB emulator device port number on the parent hub
  */
diff --git a/include/video.h b/include/video.h
index 9d09d24..31a12bd 100644
--- a/include/video.h
+++ b/include/video.h
@@ -21,7 +21,7 @@
  * struct video_uc_platdata - uclass platform data for a video device
  *
  * This holds information that the uclass needs to know about each device. It
- * is accessed using dev_get_uclass_platdata(dev). See 'Theory of operation' at
+ * is accessed using dev_get_uclass_plat(dev). See 'Theory of operation' at
  * the top of video-uclass.c for details on how this information is set.
  *
  * @align: Frame-buffer alignment, indicating the memory boundary the frame
@@ -125,7 +125,7 @@
  *
  * Note: This function is for internal use.
  *
- * This uses the uclass platdata's @size and @align members to figure out
+ * This uses the uclass plat's @size and @align members to figure out
  * a size and position for each frame buffer as part of the pre-relocation
  * process of determining the post-relocation memory layout.
  *
diff --git a/include/adc.h b/include/adc.h
index 5841dfb..0d1a666 100644
--- a/include/adc.h
+++ b/include/adc.h
@@ -40,7 +40,7 @@
 };
 
 /**
  * struct adc_uclass_platdata - basic ADC info
  *
  * Note: The positive/negative reference Voltage is only a name and it doesn't
  * provide an information about the value polarity. It is possible, for both
@@ -71,7 +71,7 @@
  * @vdd_microvolts         - positive reference Voltage value
  * @vss_microvolts         - negative reference Voltage value
  */
-struct adc_uclass_platdata {
+struct adc_uclass_plat {
 	int data_format;
 	unsigned int data_mask;
 	unsigned int data_timeout_us;
@@ -40,7 +40,7 @@
 
 /**
- * struct adc_uclass_platdata - basic ADC info
+ * struct adc_uclass_plat - basic ADC info
  *
  * Note: The positive/negative reference Voltage is only a name and it doesn't
diff --git a/include/dm/device-internal.h b/include/dm/device-internal.h
index 578a483..2e9c1d5 100644
--- a/include/dm/device-internal.h
+++ b/include/dm/device-internal.h
@@ -19,8 +19,8 @@
  * device_bind() - Create a device and bind it to a driver
  *
  * Called to set up a new device attached to a driver. The device will either
  * have platdata, or a device tree node which can be used to create the
  * platdata.
  *
  * Once bound a device exists but is not yet active until device_probe() is
  * called.
@@ -28,7 +28,7 @@
  * @parent: Pointer to device's parent, under which this driver will exist
  * @drv: Device's driver
  * @name: Name of device (e.g. device tree node name)
  * @platdata: Pointer to data for this device - the structure is device-
  * specific but may include the device's I/O address, etc.. This is NULL for
  * devices which use device tree.
  * @ofnode: Devicetree node for this device. This is ofnode_null() for
@@ -37,7 +37,7 @@
  * @return 0 if OK, -ve on error
  */
 int device_bind(struct udevice *parent, const struct driver *drv,
-		const char *name, void *platdata, ofnode node,
+		const char *name, void *plat, ofnode node,
 		struct udevice **devp);
 
 /**
@@ -72,7 +72,7 @@
  * @parent: Pointer to device's parent
  * @pre_reloc_only: If true, bind the driver only if its DM_FLAG_PRE_RELOC flag
  * is set. If false bind the driver always.
  * @info: Name and platdata for this device
  * @devp: if non-NULL, returns a pointer to the bound device
  * @return 0 if OK, -ve on error
  */
@@ -19,8 +19,8 @@
  *
  * Called to set up a new device attached to a driver. The device will either
- * have platdata, or a device tree node which can be used to create the
- * platdata.
+ * have plat, or a device tree node which can be used to create the
+ * plat.
  *
  * Once bound a device exists but is not yet active until device_probe() is
@@ -28,7 +28,7 @@
  * @drv: Device's driver
  * @name: Name of device (e.g. device tree node name)
- * @platdata: Pointer to data for this device - the structure is device-
+ * @plat: Pointer to data for this device - the structure is device-
  * specific but may include the device's I/O address, etc.. This is NULL for
  * devices which use device tree.
@@ -72,7 +72,7 @@
  * @pre_reloc_only: If true, bind the driver only if its DM_FLAG_PRE_RELOC flag
  * is set. If false bind the driver always.
- * @info: Name and platdata for this device
+ * @info: Name and plat for this device
  * @devp: if non-NULL, returns a pointer to the bound device
  * @return 0 if OK, -ve on error
diff --git a/include/dm/device.h b/include/dm/device.h
index f4c2b9b..5d31a2c 100644
--- a/include/dm/device.h
+++ b/include/dm/device.h
@@ -23,16 +23,16 @@
 /* Driver is active (probed). Cleared when it is removed */
 #define DM_FLAG_ACTIVATED		(1 << 0)
 
 /* DM is responsible for allocating and freeing platdata */
 #define DM_FLAG_ALLOC_PDATA		(1 << 1)
 
 /* DM should init this device prior to relocation */
 #define DM_FLAG_PRE_RELOC		(1 << 2)
 
 /* DM is responsible for allocating and freeing parent_platdata */
 #define DM_FLAG_ALLOC_PARENT_PDATA	(1 << 3)
 
 /* DM is responsible for allocating and freeing uclass_platdata */
 #define DM_FLAG_ALLOC_UCLASS_PDATA	(1 << 4)
 
 /* Allocate driver private data on a DMA boundary */
@@ -64,7 +64,7 @@
 /* DM does not enable/disable the power domains corresponding to this device */
 #define DM_FLAG_DEFAULT_PD_CTRL_OFF	(1 << 11)
 
 /* Driver platdata has been read. Cleared when the device is removed */
 #define DM_FLAG_PLATDATA_VALID		(1 << 12)
 
 /*
@@ -104,21 +104,21 @@
  * particular port or peripheral (essentially a driver instance).
  *
  * A device will come into existence through a 'bind' call, either due to
  * a U_BOOT_DEVICE() macro (in which case platdata is non-NULL) or a node
  * in the device tree (in which case of_offset is >= 0). In the latter case
  * we translate the device tree information into platdata in a function
  * implemented by the driver ofdata_to_platdata method (called just before the
  * probe method if the device has a device tree node.
  *
  * All three of platdata, priv and uclass_priv can be allocated by the
  * driver, or you can use the 'auto' members of struct driver and
  * struct uclass_driver to have driver model do this automatically.
  *
  * @driver: The driver used by this device
  * @name: Name of device, typically the FDT node name
  * @platdata: Configuration data for this device
  * @parent_platdata: The parent bus's configuration data for this device
  * @uclass_platdata: The uclass's configuration data for this device
  * @node: Reference to device tree node for this device
  * @driver_data: Driver data word for the entry that matched this device with
  *		its driver
@@ -142,9 +142,9 @@
 struct udevice {
 	const struct driver *driver;
 	const char *name;
-	void *platdata;
-	void *parent_platdata;
-	void *uclass_platdata;
+	void *plat;
+	void *parent_plat;
+	void *uclass_plat;
 	ofnode node;
 	ulong driver_data;
 	struct udevice *parent;
@@ -203,7 +203,7 @@
  *
  * This holds methods for setting up a new device, and also removing it.
  * The device needs information to set itself up - this is provided either
  * by platdata or a device tree node (which we find by looking up
  * matching compatible strings with of_match).
  *
  * Drivers all belong to a uclass, representing a class of devices of the
@@ -228,17 +228,17 @@
  * @priv_auto: If non-zero this is the size of the private data
  * to be allocated in the device's ->priv pointer. If zero, then the driver
  * is responsible for allocating any data required.
  * @platdata_auto: If non-zero this is the size of the
  * platform data to be allocated in the device's ->platdata pointer.
  * This is typically only useful for device-tree-aware drivers (those with
  * an of_match), since drivers which use platdata will have the data
  * provided in the U_BOOT_DEVICE() instantiation.
  * @per_child_auto: Each device can hold private data owned by
  * its parent. If required this will be automatically allocated if this
  * value is non-zero.
  * @per_child_platdata_auto: A bus likes to store information about
  * its children. If non-zero this is the size of this data, to be allocated
  * in the child's parent_platdata pointer.
  * @ops: Driver-specific operations. This is typically a list of function
  * pointers defined by the driver, to implement driver functions required by
  * the uclass.
@@ -259,9 +259,9 @@
 	int (*child_pre_probe)(struct udevice *dev);
 	int (*child_post_remove)(struct udevice *dev);
 	int priv_auto;
-	int platdata_auto;
+	int plat_auto;
 	int per_child_auto;
-	int per_child_platdata_auto;
+	int per_child_plat_auto;
 	const void *ops;	/* driver-specific operations */
 	uint32_t flags;
 #if CONFIG_IS_ENABLED(ACPIGEN)
@@ -295,24 +295,24 @@
 void *dev_get_platdata(const struct udevice *dev);
 
 /**
  * dev_get_parent_platdata() - Get the parent platform data for a device
  *
  * This checks that dev is not NULL, but no other checks for now
  *
  * @dev		Device to check
  * @return parent's platform data, or NULL if none
  */
-void *dev_get_parent_platdata(const struct udevice *dev);
+void *dev_get_parent_plat(const struct udevice *dev);
 
 /**
  * dev_get_uclass_platdata() - Get the uclass platform data for a device
  *
  * This checks that dev is not NULL, but no other checks for now
  *
  * @dev		Device to check
  * @return uclass's platform data, or NULL if none
  */
-void *dev_get_uclass_platdata(const struct udevice *dev);
+void *dev_get_uclass_plat(const struct udevice *dev);
 
 /**
  * dev_get_priv() - Get the private data for a device
@@ -622,7 +622,7 @@
 			      struct udevice **devp);
 
 /**
  * device_first_child_ofdata_err() - Find the first child and reads its platdata
  *
  * The ofdata_to_platdata() method is called on the child before it is returned,
  * but the child is not probed.
@@ -635,7 +635,7 @@
 				  struct udevice **devp);
 
 /*
  * device_next_child_ofdata_err() - Find the next child and read its platdata
  *
  * The ofdata_to_platdata() method is called on the child before it is returned,
  * but the child is not probed.
@@ -23,16 +23,16 @@
 #define DM_FLAG_ACTIVATED		(1 << 0)
 
-/* DM is responsible for allocating and freeing platdata */
+/* DM is responsible for allocating and freeing plat */
 #define DM_FLAG_ALLOC_PDATA		(1 << 1)
 
@@ -23,16 +23,16 @@
 #define DM_FLAG_PRE_RELOC		(1 << 2)
 
-/* DM is responsible for allocating and freeing parent_platdata */
+/* DM is responsible for allocating and freeing parent_plat */
 #define DM_FLAG_ALLOC_PARENT_PDATA	(1 << 3)
 
@@ -23,16 +23,16 @@
 #define DM_FLAG_ALLOC_PARENT_PDATA	(1 << 3)
 
-/* DM is responsible for allocating and freeing uclass_platdata */
+/* DM is responsible for allocating and freeing uclass_plat */
 #define DM_FLAG_ALLOC_UCLASS_PDATA	(1 << 4)
 
@@ -64,7 +64,7 @@
 #define DM_FLAG_DEFAULT_PD_CTRL_OFF	(1 << 11)
 
-/* Driver platdata has been read. Cleared when the device is removed */
+/* Driver plat has been read. Cleared when the device is removed */
 #define DM_FLAG_PLATDATA_VALID		(1 << 12)
 
@@ -104,21 +104,21 @@
  *
  * A device will come into existence through a 'bind' call, either due to
- * a U_BOOT_DEVICE() macro (in which case platdata is non-NULL) or a node
+ * a U_BOOT_DEVICE() macro (in which case plat is non-NULL) or a node
  * in the device tree (in which case of_offset is >= 0). In the latter case
@@ -104,21 +104,21 @@
  * in the device tree (in which case of_offset is >= 0). In the latter case
- * we translate the device tree information into platdata in a function
+ * we translate the device tree information into plat in a function
  * implemented by the driver ofdata_to_platdata method (called just before the
  * probe method if the device has a device tree node.
@@ -104,21 +104,21 @@
  * probe method if the device has a device tree node.
  *
- * All three of platdata, priv and uclass_priv can be allocated by the
- * driver, or you can use the 'auto' members of struct driver and
+ * All three of plat, priv and uclass_priv can be allocated by the
+ * driver, or you can use the auto_alloc_size members of struct driver and
  * struct uclass_driver to have driver model do this automatically.
  *
@@ -104,21 +104,21 @@
  * @driver: The driver used by this device
  * @name: Name of device, typically the FDT node name
- * @platdata: Configuration data for this device
- * @parent_platdata: The parent bus's configuration data for this device
- * @uclass_platdata: The uclass's configuration data for this device
+ * @plat: Configuration data for this device
+ * @parent_plat: The parent bus's configuration data for this device
+ * @uclass_plat: The uclass's configuration data for this device
  * @node: Reference to device tree node for this device
  * @driver_data: Driver data word for the entry that matched this device with
@@ -203,7 +203,7 @@
  * This holds methods for setting up a new device, and also removing it.
  * The device needs information to set itself up - this is provided either
- * by platdata or a device tree node (which we find by looking up
+ * by plat or a device tree node (which we find by looking up
  * matching compatible strings with of_match).
  *
@@ -228,17 +228,17 @@
  * to be allocated in the device's ->priv pointer. If zero, then the driver
  * is responsible for allocating any data required.
- * @platdata_auto: If non-zero this is the size of the
- * platform data to be allocated in the device's ->platdata pointer.
+ * @plat_auto: If non-zero this is the size of the
+ * platform data to be allocated in the device's ->plat pointer.
  * This is typically only useful for device-tree-aware drivers (those with
@@ -228,17 +228,17 @@
  * This is typically only useful for device-tree-aware drivers (those with
- * an of_match), since drivers which use platdata will have the data
+ * an of_match), since drivers which use plat will have the data
  * provided in the U_BOOT_DEVICE() instantiation.
  * @per_child_auto: Each device can hold private data owned by
@@ -228,17 +228,17 @@
  * its parent. If required this will be automatically allocated if this
  * value is non-zero.
- * @per_child_platdata_auto: A bus likes to store information about
+ * @per_child_plat_auto: A bus likes to store information about
  * its children. If non-zero this is the size of this data, to be allocated
@@ -228,17 +228,17 @@
  * its children. If non-zero this is the size of this data, to be allocated
- * in the child's parent_platdata pointer.
+ * in the child's parent_plat pointer.
  * @ops: Driver-specific operations. This is typically a list of function
  * pointers defined by the driver, to implement driver functions required by
@@ -295,24 +295,24 @@
 
 /**
- * dev_get_parent_platdata() - Get the parent platform data for a device
+ * dev_get_parent_plat() - Get the parent platform data for a device
  *
  * This checks that dev is not NULL, but no other checks for now
@@ -295,24 +295,24 @@
 
 /**
- * dev_get_uclass_platdata() - Get the uclass platform data for a device
+ * dev_get_uclass_plat() - Get the uclass platform data for a device
  *
  * This checks that dev is not NULL, but no other checks for now
@@ -622,7 +622,7 @@
 
 /**
- * device_first_child_ofdata_err() - Find the first child and reads its platdata
+ * device_first_child_ofdata_err() - Find the first child and reads its plat
  *
  * The ofdata_to_platdata() method is called on the child before it is returned,
@@ -635,7 +635,7 @@
 
 /*
- * device_next_child_ofdata_err() - Find the next child and read its platdata
+ * device_next_child_ofdata_err() - Find the next child and read its plat
  *
  * The ofdata_to_platdata() method is called on the child before it is returned,
diff --git a/include/dm/uclass.h b/include/dm/uclass.h
index e74082f..068e8ea 100644
--- a/include/dm/uclass.h
+++ b/include/dm/uclass.h
@@ -71,15 +71,15 @@
  * @per_device_auto: Each device can hold private data owned
  * by the uclass. If required this will be automatically allocated if this
  * value is non-zero.
  * @per_device_platdata_auto: Each device can hold platform data
  * owned by the uclass as 'dev->uclass_platdata'. If the value is non-zero,
  * then this will be automatically allocated.
  * @per_child_auto: Each child device (of a parent in this
  * uclass) can hold parent data for the device/uclass. This value is only
  * used as a fallback if this member is 0 in the driver.
  * @per_child_platdata_auto: A bus likes to store information about
  * its children. If non-zero this is the size of this data, to be allocated
  * in the child device's parent_platdata pointer. This value is only used as
  * a fallback if this member is 0 in the driver.
  * @ops: Uclass operations, providing the consistent interface to devices
  * within the uclass.
@@ -100,9 +100,9 @@
 	int (*destroy)(struct uclass *class);
 	int priv_auto;
 	int per_device_auto;
-	int per_device_platdata_auto;
+	int per_device_plat_auto;
 	int per_child_auto;
-	int per_child_platdata_auto;
+	int per_child_plat_auto;
 	const void *ops;
 	uint32_t flags;
 };
@@ -71,15 +71,15 @@
  * by the uclass. If required this will be automatically allocated if this
  * value is non-zero.
- * @per_device_platdata_auto: Each device can hold platform data
- * owned by the uclass as 'dev->uclass_platdata'. If the value is non-zero,
+ * @per_device_plat_auto: Each device can hold platform data
+ * owned by the uclass as 'dev->uclass_plat'. If the value is non-zero,
  * then this will be automatically allocated.
  * @per_child_auto: Each child device (of a parent in this
@@ -71,15 +71,15 @@
  * uclass) can hold parent data for the device/uclass. This value is only
  * used as a fallback if this member is 0 in the driver.
- * @per_child_platdata_auto: A bus likes to store information about
+ * @per_child_plat_auto: A bus likes to store information about
  * its children. If non-zero this is the size of this data, to be allocated
@@ -71,15 +71,15 @@
  * its children. If non-zero this is the size of this data, to be allocated
- * in the child device's parent_platdata pointer. This value is only used as
+ * in the child device's parent_plat pointer. This value is only used as
  * a fallback if this member is 0 in the driver.
  * @ops: Uclass operations, providing the consistent interface to devices
diff --git a/include/power/regulator.h b/include/power/regulator.h
index 7f278e8..19a3b7b 100644
--- a/include/power/regulator.h
+++ b/include/power/regulator.h
@@ -16,15 +16,15 @@
  * 'UCLASS_REGULATOR' and the regulator driver API.
  *
  * The regulator uclass - is based on uclass platform data which is allocated,
  * automatically for each regulator device on bind and 'dev->uclass_platdata'
  * points to it. The data type is: 'struct dm_regulator_uclass_platdata'.
  * The uclass file: 'drivers/power/regulator/regulator-uclass.c'
  *
  * The regulator device - is based on driver's model 'struct udevice'.
  * The API can use regulator name in two meanings:
  * - devname  - the regulator device's name: 'dev->name'
  * - platname - the device's platdata's name. So in the code it looks like:
  *              'uc_pdata = dev->uclass_platdata'; 'name = uc_pdata->name'.
  *
  * The regulator device driver - provide an implementation of uclass operations
  * pointed by 'dev->driver->ops' as a struct of type 'struct dm_regulator_ops'.
@@ -135,7 +135,7 @@
 };
 
 /**
  * struct dm_regulator_uclass_platdata - pointed by dev->uclass_platdata, and
  * allocated on each regulator bind. This structure holds an information
  * about each regulator's constraints and supported operation modes.
  * There is no "step" voltage value - so driver should take care of this.
@@ -162,7 +162,7 @@
  * The constraints: type, mode, mode_count, can be set by device driver, e.g.
  * by the driver '.probe' method.
  */
-struct dm_regulator_uclass_platdata {
+struct dm_regulator_uclass_plat {
 	enum regulator_type type;
 	struct dm_regulator_mode *mode;
 	int mode_count;
@@ -422,7 +422,7 @@
  * regulator_autoset: setup the voltage/current on a regulator
  *
  * The setup depends on constraints found in device's uclass's platform data
- * (struct dm_regulator_uclass_platdata):
+ * (struct dm_regulator_uclass_plat):
  *
  * - Enable - will set - if any of: 'always_on' or 'boot_on' is set to true,
  *   or if both are unset, then the function returns
@@ -431,7 +431,7 @@
  *
  * The function returns on the first-encountered error.
  *
  * @platname - expected string for dm_regulator_uclass_platdata .name field
  * @devp     - returned pointer to the regulator device - if non-NULL passed
  * @return: 0 on success or negative value of errno.
  */
@@ -440,7 +440,7 @@
 /**
  * regulator_autoset_by_name: setup the regulator given by its uclass's
  * platform data name field. The setup depends on constraints found in device's
- * uclass's platform data (struct dm_regulator_uclass_platdata):
+ * uclass's platform data (struct dm_regulator_uclass_plat):
  * - Enable - will set - if any of: 'always_on' or 'boot_on' is set to true,
  *   or if both are unset, then the function returns
  * - Voltage value - will set - if '.min_uV' and '.max_uV' values are equal
@@ -448,7 +448,7 @@
  *
  * The function returns on first encountered error.
  *
  * @platname - expected string for dm_regulator_uclass_platdata .name field
  * @devp     - returned pointer to the regulator device - if non-NULL passed
  * @return: 0 on success or negative value of errno.
  *
@@ -464,7 +464,7 @@
  * regulator_autoset_by_name() for each name from the list.
  *
  * @list_platname - an array of expected strings for .name field of each
- *                  regulator's uclass platdata
+ *                  regulator's uclass plat
  * @list_devp     - an array of returned pointers to the successfully setup
  *                  regulator devices if non-NULL passed
  * @verbose       - (true/false) print each regulator setup info, or be quiet
@@ -499,9 +499,9 @@
 
 /**
  * regulator_get_by_platname: returns the pointer to the pmic regulator device.
  * Search by name, found in regulator uclass platdata.
  *
  * @platname - expected string for uc_pdata->name of regulator uclass platdata
  * @devp     - returns pointer to the regulator device or NULL on error
  * @return 0 on success or negative value of errno.
  *
@@ -16,15 +16,15 @@
  *
  * The regulator uclass - is based on uclass platform data which is allocated,
- * automatically for each regulator device on bind and 'dev->uclass_platdata'
- * points to it. The data type is: 'struct dm_regulator_uclass_platdata'.
+ * automatically for each regulator device on bind and 'dev->uclass_plat'
+ * points to it. The data type is: 'struct dm_regulator_uclass_plat'.
  * The uclass file: 'drivers/power/regulator/regulator-uclass.c'
  *
@@ -16,15 +16,15 @@
  * The API can use regulator name in two meanings:
  * - devname  - the regulator device's name: 'dev->name'
- * - platname - the device's platdata's name. So in the code it looks like:
- *              'uc_pdata = dev->uclass_platdata'; 'name = uc_pdata->name'.
+ * - platname - the device's plat's name. So in the code it looks like:
+ *              'uc_pdata = dev->uclass_plat'; 'name = uc_pdata->name'.
  *
  * The regulator device driver - provide an implementation of uclass operations
@@ -135,7 +135,7 @@
 
 /**
- * struct dm_regulator_uclass_platdata - pointed by dev->uclass_platdata, and
+ * struct dm_regulator_uclass_plat - pointed by dev->uclass_plat, and
  * allocated on each regulator bind. This structure holds an information
  * about each regulator's constraints and supported operation modes.
@@ -431,7 +431,7 @@
  * The function returns on the first-encountered error.
  *
- * @platname - expected string for dm_regulator_uclass_platdata .name field
+ * @platname - expected string for dm_regulator_uclass_plat .name field
  * @devp     - returned pointer to the regulator device - if non-NULL passed
  * @return: 0 on success or negative value of errno.
@@ -448,7 +448,7 @@
  * The function returns on first encountered error.
  *
- * @platname - expected string for dm_regulator_uclass_platdata .name field
+ * @platname - expected string for dm_regulator_uclass_plat .name field
  * @devp     - returned pointer to the regulator device - if non-NULL passed
  * @return: 0 on success or negative value of errno.
@@ -499,9 +499,9 @@
 /**
  * regulator_get_by_platname: returns the pointer to the pmic regulator device.
- * Search by name, found in regulator uclass platdata.
+ * Search by name, found in regulator uclass plat.
  *
@@ -499,9 +499,9 @@
  *
- * @platname - expected string for uc_pdata->name of regulator uclass platdata
+ * @platname - expected string for uc_pdata->name of regulator uclass plat
  * @devp     - returns pointer to the regulator device or NULL on error
  * @return 0 on success or negative value of errno.